@@ -106,6 +106,7 @@ impl WinitWindowBackend {
                 opengl_version: (3, 3),
                 opengles_version: (3, 0),
             })
+            .with_srgb(true)
             .with_gl_profile(glutin::GlProfile::Core)
             .with_multisampling(config.multisampling)
             .build_windowed(builder, event_loop)
@@ -163,5 +164,15 @@ fn winit_cursor(cursor: CursorIcon) -> Option<WCursorIcon> {
         CursorIcon::ResizeVertical => WCursorIcon::NsResize,
         CursorIcon::ZoomIn => WCursorIcon::ZoomIn,
         CursorIcon::ZoomOut => WCursorIcon::ZoomOut,
+        CursorIcon::ResizeEast => WCursorIcon::EResize,
+        CursorIcon::ResizeSouthEast => WCursorIcon::SeResize,
+        CursorIcon::ResizeSouth => WCursorIcon::SResize,
+        CursorIcon::ResizeSouthWest => WCursorIcon::SwResize,
+        CursorIcon::ResizeWest => WCursorIcon::WResize,
+        CursorIcon::ResizeNorthWest => WCursorIcon::NwResize,
+        CursorIcon::ResizeNorth => WCursorIcon::NResize,
+        CursorIcon::ResizeNorthEast => WCursorIcon::NeResize,
+        CursorIcon::ResizeColumn => WCursorIcon::ColResize,
+        CursorIcon::ResizeRow => WCursorIcon::RowResize,
     })
 }
